#!/bin/bash

agent_bin_folder=$(pwd)
configuration_files_folder=$1
app_data_folder=$2
libexec_folder=$3

echo "MODIFY_PAM: configuration_files_folder:" $configuration_files_folder
echo "MODIFY_PAM: app_data_folder:" $app_data_folder
echo "MODIFY_PAM: libexec_folder:" $libexec_folder

if [ ! -d ${configuration_files_folder} ]; then
    echo "MODIFY_PAM: no configuration files folder" 1>&2
    exit 2 # not an error
fi

check_file () {
    diff /etc/pam.d/$1 ${configuration_files_folder}/pam.d/$1$2  -y --suppress-common-lines
    if [ $? -ne 0 ]; then
        check_file_failed=1
        if [ -z $3 ]; then
            echo "MODIFY_PAM: Error: $1 files are not the same" 1>&2
            exit 1
        fi
    fi
}

modify_agent_path () {
    echo "MODIFY_PAM: replacing agent_bin_folder to" ${libexec_folder} "in" ${configuration_files_folder}/pam.d/$1.modified 1>&2
    sed -e "s|{AGENT_BIN_DIR}|${libexec_folder}|g" ${configuration_files_folder}/pam.d/$1.modified > ${configuration_files_folder}/pam.d/$1.tmp
    mv ${configuration_files_folder}/pam.d/$1.tmp ${configuration_files_folder}/pam.d/$1.modified
}

overwrite_file () {
   echo "MODIFY_PAM: overwriting" /etc/pam.d/$1 1>&2
    cp -f ${configuration_files_folder}/pam.d/$1.modified /etc/pam.d/$1
    chown root /etc/pam.d/$1
}

if [ "$(id -u)" != "0" ]; then
   echo "MODIFY_PAM: This script must be run as root" 1>&2
   exit 1
fi

modify_agent_path "sshd"
modify_agent_path "login"
modify_agent_path "common-auth"

check_file_failed=0

check_file "sshd" ".modified" 1
check_file "login" ".modified" 1
check_file "common-auth" ".modified" 1

if [ $check_file_failed -eq 0 ]; then
    echo "MODIFY_PAM: Environment already set" 1>&2
    exit 0
fi

echo 'MODIFY_PAM: Modifying PAM configuration files to audit login events'

check_file "sshd"
check_file "common-auth"
check_file "login"

overwrite_file "sshd"
overwrite_file "common-auth"
overwrite_file "login"

check_file "sshd" ".modified"
check_file "common-auth" ".modified"
check_file "login" ".modified"

echo 'MODIFY_PAM: Modifying PAM configuration files finished successfully'
exit 0